==> drd-4.1.0-rc3.tar.gz: drd/src/Entity/ViewBuilder/Base.php <==
<?php

namespace Drupal\drd\Entity\ViewBuilder;

use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\drd\Form\EntityActions;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * View builder handler for DRD Entities.
 *
 * @ingroup drd
 */
abstract class Base extends EntityViewBuilder {

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected FormBuilderInterface $formBuilder;

  /**
   * The date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected DateFormatterInterface $dateFormatter;

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type): Base {
    /** @var \Drupal\drd\Entity\ViewBuilder\Base $instance */
    $instance = parent::createInstance($container, $entity_type);
    $instance->formBuilder = $container->get('form_builder');
    $instance->dateFormatter = $container->get('date.formatter');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function buildComponents(array &$build, array $entities, array $displays, $view_mode): void {
    /** @var \Drupal\drd\Entity\BaseInterface[] $entities */
    if (empty($entities)) {
      return;
    }

    parent::buildComponents($build, $entities, $displays, $view_mode);

    foreach ($entities as $id => $entity) {
      $bundle = $entity->bundle();
      $display = $displays[$bundle];

      if ($display->getComponent('actions')) {
        $build[$id]['actions'] = $this->formBuilder->getForm(EntityActions::class);
      }
    }
  }

}

==> drd-4.1.2.tar.gz: drd/src/Entity/ViewBuilder/Base.php <==
<?php

namespace Drupal\drd\Entity\ViewBuilder;

use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\drd\Form\EntityActions;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * View builder handler for DRD Entities.
 *
 * @ingroup drd
 */
abstract class Base extends EntityViewBuilder {

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected FormBuilderInterface $formBuilder;

  /**
   * The date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected DateFormatterInterface $dateFormatter;

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type): static {
    $instance = parent::createInstance($container, $entity_type);
    $instance->formBuilder = $container->get('form_builder');
    $instance->dateFormatter = $container->get('date.formatter');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function buildComponents(array &$build, array $entities, array $displays, $view_mode): void {
    /** @var \Drupal\drd\Entity\BaseInterface[] $entities */
    if (empty($entities)) {
      return;
    }

    parent::buildComponents($build, $entities, $displays, $view_mode);

    foreach ($entities as $id => $entity) {
      $bundle = $entity->bundle();
      $display = $displays[$bundle];

      if ($display->getComponent('actions')) {
        $build[$id]['actions'] = $this->formBuilder->getForm(EntityActions::class);
      }
    }
  }

}
